import type { RouteRecordRaw } from 'vue-router'
import Dashboard from '@/pages/Dashboard.vue'
import Default from '@/layouts/Default.vue'
import { useUserStore } from '@/stores/user'

const handleUser = (loggedCb?: () => void, notLoggedCb?: () => void) => {
  const { user } = useUserStore()
  if (user) return loggedCb?.()
  return notLoggedCb?.()
}

export const routes: RouteRecordRaw[] = [
  {
    path: '/',
    name: 'Locale',
    meta: { layout: Default },
    children: [
      {
        path: '',
        name: 'Dashboard',
        component: Dashboard,
        beforeEnter: () => handleUser(undefined, () => ({ name: 'Login' }))
      },
      {
        path: '/login',
        name: 'Login',
        component: () => import('@/pages/Login.vue'),
        beforeEnter: () => handleUser(() => ({ name: 'Dashboard' }))
      },
      {
        path: '/register',
        name: 'Register',
        component: () => import('@/pages/Register.vue'),
        beforeEnter: () => handleUser(() => ({ name: 'Dashboard' }))
      }
    ]
  },
  {
    path: '/404',
    name: 'NotFound',
    component: () => import('@/pages/NotFound.vue'),
    meta: { layout: Default }
  },
  {
    path: '/:catchAll(.*)',
    redirect: '/404'
  }
]
