import { ref } from 'vue'
import { defineStore } from 'pinia'
import { login as apiLogin, register as apiRegister, type User } from '@/api/user'

const USER_LOCAL_STORAGE_KEY = 'user'

export const useUserStore = defineStore('user', () => {
  const user = ref<User | null>(JSON.parse(localStorage.getItem(USER_LOCAL_STORAGE_KEY) || 'null'))

  const login = async (_email: string, _password: string) => {
    try {
      user.value = await apiLogin(_email, _password)
      localStorage.setItem(USER_LOCAL_STORAGE_KEY, JSON.stringify(user.value))
    } catch (e) {
      throw new Error('Email or password is incorrect!')
    }
  }

  const register = async (_name: string, _email: string, _password: string) => {
    try {
      user.value = await apiRegister(_name, _email, _password)
      localStorage.setItem(USER_LOCAL_STORAGE_KEY, JSON.stringify(user.value))
    } catch (e) {
      throw new Error('User is already registered! Please log in.')
    }
  }

  const logout = () => {
    localStorage.removeItem(USER_LOCAL_STORAGE_KEY)
    user.value = null
  }

  return { user, login, logout, register }
})
